@@ -5,8 +5,8 @@
 
 
 #define NXT_CONFIGURE_OPTIONS  " --prefix=/usr/pkg --ld-opt='-L/usr/pkg/lib -R/usr/pkg/lib' --pkgconfigdir=/usr/pkg/lib/pkgconfig --no-regex --prefix=/usr/pkg --ld-opt='-L/usr/pkg/lib -R/usr/pkg/lib' --log=/var/log/unit/unit.log --logdir=/var/log/unit --modulesdir=/usr/pkg/libexec/unit/modules --pid=/var/run/unit.pid --runstatedir=/var/run/unit --statedir=/var/db/unit --control=unix:/var/run/unit/control.unit.sock --tmpdir=/var/tmp --user=unit --group=unit --mandir=/usr/pkg/man --openssl"
-#define NXT_SYSTEM_VERSION     "NetBSD 10.0 evbarm"
-#define NXT_COMPILER_VERSION   "gcc version 10.5.0 (nb3 20231008) "
+#define NXT_SYSTEM_VERSION     "NetBSD 11.0 mac68k"
+#define NXT_COMPILER_VERSION   "gcc version 12.5.0 (nb1 20250721) "
 
 #define NXT_PID                "/var/run/unit.pid"
 #define NXT_LOG                "/var/log/unit/unit.log"
@@ -30,8 +30,8 @@
 #endif
 
 
-#ifndef NXT_HAVE_LITTLE_ENDIAN
-#define NXT_HAVE_LITTLE_ENDIAN  1
+#ifndef NXT_HAVE_BIG_ENDIAN
+#define NXT_HAVE_BIG_ENDIAN  1
 #endif
 
 
@@ -41,7 +41,7 @@
 
 
 #ifndef NXT_LONG_SIZE
-#define NXT_LONG_SIZE  8
+#define NXT_LONG_SIZE  4
 #endif
 
 
@@ -51,12 +51,12 @@
 
 
 #ifndef NXT_PTR_SIZE
-#define NXT_PTR_SIZE  8
+#define NXT_PTR_SIZE  4
 #endif
 
 
 #ifndef NXT_SIZE_T_SIZE
-#define NXT_SIZE_T_SIZE  8
+#define NXT_SIZE_T_SIZE  4
 #endif
 
 
@@ -70,11 +70,6 @@
 #endif
 
 
-#ifndef NXT_HAVE_C99_VARIADIC_MACRO
-#define NXT_HAVE_C99_VARIADIC_MACRO  1
-#endif
-
-
 #ifndef NXT_HAVE_BUILTIN_EXPECT
 #define NXT_HAVE_BUILTIN_EXPECT  1
 #endif
@@ -125,6 +120,11 @@
 #endif
 
 
+#ifndef NXT_HAVE_GCC_ATTRIBUTE_NONSTRING
+#define NXT_HAVE_GCC_ATTRIBUTE_NONSTRING  1
+#endif
+
+
 #ifndef NXT_HAVE_GCC_ATOMIC
 #define NXT_HAVE_GCC_ATOMIC  1
 #endif
@@ -296,7 +296,7 @@
 
 
 #ifndef NXT_HAVE_OPENSSL_VERSION
-#define NXT_HAVE_OPENSSL_VERSION  "OpenSSL 3.0.12 24 Oct 2023"
+#define NXT_HAVE_OPENSSL_VERSION  "OpenSSL 3.5.1 1 Jul 2025"
 #endif
 
 
